# Appliance dumps

- [003](003.md): ASKO professional washing machine
- [004](004.md): ASKO professional tumble dryer
- [006](006.md): Air conditioner
- [007](007.md): Dehumidifier
- [009](009.md): Air conditioner
- [010](010.md): ASKO induction hob
- [012](012.md): ASKO hood
- [013](013.md): Oven
- [015](015.md): ASKO dishwasher
- [016](016.md): Heat pump
- [020](020.md): ASKO induction hob
- [021](021.md): ASKO hood
- [023](023.md): Atag oven
- [025](025.md): Washing Machine
- [026](026.md): Hisense refrigerator
- [027](027.md): Washing Machine
- [030](030.md): Dryer
- [032](032.md): Tumble Dryer
